package Tests::md5_check;

use Tests::Base;
@ISA = qw( Tests::Base );

use DB_File;

sub execute
{
	my $self = shift;
	my( %hash );
	my $host = $self -> host_addr();
	my $file = $self -> opt( 'file' );
	my $hfkey = "$host,$file";

	my $foo = $self -> probe( undef, $file );

	tie %hash, 'DB_File', 'data/md5_check';

	if( $foo == 200 )
	{
		# Validate MD5 data
		if( $hash{ $hfkey } )
		{
			if( $hash{ $hfkey } ne $self -> probe_message() )
			{
				$self -> message( "ALERT! File '$file' on host $host has changed!" );
				return( 1 );
			}

			$self -> logmsg( "Size/MD5 match" );
			return( 0 );
		}else
		{
			$self -> message( qq{Warning: adding new MD5 data for '$file' on $host.  
YOU SHOULD GET THIS ONLY ONCE PER FILE/HOST,
OTHERWISE YOUR MD5 DATABASE MAY HAVE BEEN DELETED} );

			$hash{ $hfkey } = $self -> probe_message(); # This is a combo size/md5
			return( 1 );
		}
	}

	$self -> message( $self -> probe_message() );
	return( 1 );
}

1;

__END__

=head1 NAME

Tests::md5_check - validates md5 hashes of files, requires probe

=head1 SYNOPSIS

	<md5_check file="/path/to/file"/>

=head1 DESCRIPTION

Checks and validates the md5 sums of files, and sends out notifications when files change
unexpectedly.  A simple way to catch installed rootkits on compromised servers, and can
be used with "onfail" and chained to lock down the server from the network when a problem
is detected.  Common files to check include /bin/login, /sbin/ifconfig, /bin/netstat, etc.

On the first run notifications will be sent out about adding new data, to catch against
having the md5 database deleted unexpectedly.  If the system is upgraded and binaries are
changed, the md5_check file should be deleted to cause the database to be rebuilt.  The
md5_check file resides in the data/ directory under the main sentinel installation.

=head2 file

Full path to the file to monitor

=head1 SEE ALSO

sentinel, probe, librarian, sentinel.conf

=head1 AUTHOR

Steve Slaven - http://hoopajoo.net
